BREAKPOINT_THRESHOLD = 0.85

CORE_ACCOUNTS = [
    "자산총계", "부채총계", "자본총계",
    "매출액", "영업이익", "당기순이익",
    "유동자산", "비유동자산", "유동부채", "비유동부채",
]

EXACT_MATCH_TOLERANCE = 0.5
RESTATEMENT_NAME_SIMILARITY = 0.8
RESTATEMENT_AMOUNT_TOLERANCE = 0.05
NAME_CHANGE_SIMILARITY = 0.6
NAME_CHANGE_AMOUNT_TOLERANCE = 0.05
