"""내부통제 분석 모듈."""

from dartlab.finance.internalControl.pipeline import internalControl
from dartlab.finance.internalControl.types import InternalControlResult

__all__ = ["internalControl", "InternalControlResult"]
