"""대주주 거래 분석 모듈."""

from dartlab.finance.relatedPartyTx.pipeline import relatedPartyTx
from dartlab.finance.relatedPartyTx.types import RelatedPartyTxResult

__all__ = ["relatedPartyTx", "RelatedPartyTxResult"]
